/**
 * Dropdown component
 * @class ApDropdown
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _apemanReactSpinner = require('apeman-react-spinner');

var _apemanReactMixinPure = require('apeman-react-mixin-pure');

var _apemanReactMixinLayout = require('apeman-react-mixin-layout');

var _apemanReactMixinOutside = require('apeman-react-mixin-outside');

var _apemanReactButton = require('apeman-react-button');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @lends ApDropdown */
var ApDropdown = _react2.default.createClass({
  displayName: 'ApDropdown',


  // --------------------
  // Specs
  // --------------------

  propTypes: {
    /** Icon class name for open state */
    openIcon: _react.PropTypes.string,
    /** Icon class name for closed state */
    closedIcon: _react.PropTypes.string,
    /** Show spinner */
    spinning: _react.PropTypes.bool,
    /** Spinner theme */
    spinner: _react.PropTypes.string,
    /** Open or not */
    open: _react.PropTypes.bool.isRequired,
    /** Handler for tap event */
    onTap: _react.PropTypes.func.isRequired
  },

  mixins: [_apemanReactMixinLayout.ApLayoutMixin, _apemanReactMixinOutside.ApOutsideMixin],

  statics: {},

  getInitialState: function getInitialState() {
    return {
      open: false
    };
  },
  getDefaultProps: function getDefaultProps() {
    return {
      openIcon: 'ion ion-chevron-up',
      closedIcon: 'ion ion-chevron-down',
      spinning: false,
      spinner: _apemanReactSpinner.ApSpinner.DEFAULT_THEME
    };
  },
  render: function render() {
    var s = this;
    var state = s.state;
    var props = s.props;
    var layouts = s.layouts;


    return _react2.default.createElement(
      'div',
      { className: (0, _classnames2.default)('ap-dropdown', {
          'ap-dropdown-open': props.open,
          'ap-dropdown-closed': !props.open
        }, props.className),
        style: Object.assign({}, props.style) },
      s._renderSpinner(),
      _react2.default.createElement(
        'div',
        { className: 'ap-dropdown-button-wrap' },
        _react2.default.createElement(
          _apemanReactButton.ApButton,
          { className: 'ap-dropdown-button', onTap: s.handleButtonTap },
          props.title,
          _react2.default.createElement('i', { className: (0, _classnames2.default)('ap-dropdown-icon', props.open ? props.openIcon : props.closedIcon) })
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'ap-dropdown-content', style: layouts.content },
        _react2.default.createElement(
          'div',
          { className: 'ap-dropdown-content-inner',
            ref: function ref(inner) {
              return s.registerContentInner(inner);
            } },
          props.children
        )
      )
    );
  },


  // --------------------
  // Lifecycle
  // --------------------

  componentWillMount: function componentWillMount() {
    var s = this;
  },
  componentDidMount: function componentDidMount() {
    var s = this;
    s.layout();
  },


  // ------------------
  // For ApLayoutMixin
  // ------------------

  getInitialLayouts: function getInitialLayouts() {
    return {
      content: null
    };
  },
  calcLayouts: function calcLayouts() {
    var s = this;
    var contentInner = s.contentInner;

    var contentRect = contentInner.getBoundingClientRect();
    return {
      content: {
        height: contentRect.height
      }
    };
  },


  // ------------------
  // Custom
  // ------------------

  contentInner: null,

  registerContentInner: function registerContentInner(contentInner) {
    var s = this;
    s.contentInner = contentInner;
  },
  handleButtonTap: function handleButtonTap(e) {
    var s = this;
    var props = s.props;

    props.onTap(e);
  },


  // ------------------
  // Private
  // ------------------
  _renderSpinner: function _renderSpinner() {
    var s = this;
    var props = s.props;

    if (!props.spinning) {
      return null;
    }
    return _react2.default.createElement(
      'div',
      { className: 'ap-dropdown-spinner-cover' },
      _react2.default.createElement(_apemanReactSpinner.ApSpinner, { theme: props.spinner,
        className: 'ap-dropdown-spinner',
        enabled: true })
    );
  }
});

exports.default = ApDropdown;
//# sourceMappingURL=data:application/json;base64,bnVsbA==